@@ -22,10 +22,10 @@ class clock:
         print('Elapsed time: ',clock.end_t - clock.start_t)
 
 def box_plot(scalled_posteriors,path_to_save):
-    traces = []
+    fig = go.Figure()
     ii = 0
     for key,value in scalled_posteriors.items():
-        traces.append(go.Box(
+        fig.add_trace(go.Box(
             y=value,
             name=key,
             boxpoints='all',
@@ -35,7 +35,7 @@ def box_plot(scalled_posteriors,path_to_save):
             line_width=2)
                      )
         ii += 1
-    layout = go.Layout(yaxis=dict(
+    fig.update_layout(yaxis=dict(
     #                             autorange=True,
     #                             showgrid=False,
                                 dtick=0.2,
@@ -51,8 +51,7 @@ def box_plot(scalled_posteriors,path_to_save):
                         paper_bgcolor='rgb(243, 243, 243)',
                         plot_bgcolor='rgb(243, 243, 243)',
                        )
-    fig = { "data": traces,"layout":layout }
-    plotly.io.write_image(fig = { "data": traces,"layout":layout }, file=path_to_save+'/box_plot.svg',format="svg",scale=None, width=None, height=None)
+    fig.write_html(path_to_save+'/box_plot.html')
     
 class ABC:
 
